==> fetch.php?media=snfit-2.2.2.tar.gz: snfit-2.2.2/src/fittedsn.h <==


#ifndef FITTEDSN__H
#define FITTEDSN__H
#include <list>
#include <string>
#include <vector>
#include <math.h>
#include "param.h"
#include "countedref.h"
#include "dictfile.h"
#include "lcmodels.h"

// code for host galaxy classification
#define NO_HOST -1
#define NOT_OK -100


using namespace std;


//--------------------------------------------------------

/* NAME  R4D4-14_simul */
/* REDSHIFT 0.28 */
/* CCD ccd_24 */
/* RA 22:14:45.806 */
/* Dec -17:44:22.95 */
/* canadname c030622-07 */
/* Run Run4 */
/* Field  D4 */
/* MWEBV  0.0 */
/* HOSTGALEBV  0.556847  */

//---------------------------------------------
  



class AllSn;

class FittedSn : public RefCount{
  
  friend class AllSn;
  
  private :
    
  string Name;
  double RedShift;
  int Gal_Type ;
  double mwEbv;
  FitParams params;
  int group; // this is just for display
  LcModel model; // which lc fitter was used
  int Set; 

  
  public :

    FittedSn ();
  virtual ~FittedSn();
  const string&  GetName() const {return Name;};
  double GetZ () const {return RedShift;};
  int GetGType () const {return Gal_Type;};
  const FitParams&  GetParams() const {return params;};
  int GetGroup() const {return group;};
  void SetGroup(int g) {group = g;};
  const FitParams* Params() const {return &params;};
  int GetSet() const {return Set;};
  void SetSet(int i) {Set=i;};
  

  LcParam *mag;   // SN magnitude
  LcParam *shape; // SN light-curve shape parameter (stretch-1 for SALT1 or SIFTO, X1 for SALT2)
  LcParam *color; // SN color
  


  // R&D things
  
 
#ifdef WITH_HOST_EXTINCTION
  private : 
  bool has_extinction_measurement; // EBV with Cardelli law
  public :
  bool HasExtinctionMeasurement() const {return has_extinction_measurement;};
  LcParam *ebv;
#endif

#ifdef WITH_UV_FIT
 private :
  bool has_uv_fit; 
 public :
  bool HasUVFit() const {return has_uv_fit;};
  LcParam *uv;
#endif

};


class AllSn : public list<CountedRef<FittedSn> >

{

  private :
    int number_of_salt2_components; // X0 X1 ...
  LcModel model; // which lc fitter was used
  vector<int> galaxy_types;
#ifdef WITH_HOST_EXTINCTION 
  bool has_extinction_measurement; // EBV with Cardelli law
#endif
#ifdef WITH_UV_FIT
  bool has_uv_fit; 
#endif
  
  public :
    AllSn () {
    number_of_salt2_components=2;
    model=UNKNOWN;
#ifdef WITH_HOST_EXTINCTION 
    has_extinction_measurement=false;
#endif
#ifdef WITH_UV_FIT
    has_uv_fit=false;
#endif
    };
  void ReadDictFile(const string& dictfilename);  
  LcModel GetLcModel() const {return model;};
#ifdef WITH_HOST_EXTINCTION 
  bool HasExtinctionMeasurement() const {return has_extinction_measurement;};
#endif
#ifdef WITH_UV_FIT
  bool HasUVFit() const {return has_uv_fit;};
#endif

  ~AllSn() {};
  int NumberOfSALT2Components() const {return number_of_salt2_components;};
  void SetNumberOfSALT2Components(int n)  {number_of_salt2_components=n;};
  size_t NumberOfGalaxyTypes() const {return galaxy_types.size();};
  

};

typedef AllSn::iterator SnIterator;
typedef AllSn::const_iterator SnCIterator;



#endif /* FITTEDSN__H */

==> fetch.php?media=snfit-2.4.1.tar.gz: snfit-2.4.2/src/fittedsn.h <==


#ifndef FITTEDSN__H
#define FITTEDSN__H
#include <list>
#include <string>
#include <vector>
#include <math.h>
#include "param.h"
#include "countedref.h"
#include "dictfile.h"
#include "lcmodels.h"

// code for host galaxy classification
#define NO_HOST -1
#define NOT_OK -100



//--------------------------------------------------------

/* NAME  R4D4-14_simul */
/* REDSHIFT 0.28 */
/* CCD ccd_24 */
/* RA 22:14:45.806 */
/* Dec -17:44:22.95 */
/* canadname c030622-07 */
/* Run Run4 */
/* Field  D4 */
/* MWEBV  0.0 */
/* HOSTGALEBV  0.556847  */

//---------------------------------------------
  



class AllSn;

class FittedSn : public RefCount{
  
  friend class AllSn;
  
  private :
    
  std::string Name;
  double RedShift;
  int Gal_Type ;
  double mwEbv;
  FitParams params;
  int group; // this is just for display
  LcModel model; // which lc fitter was used
  int Set; 

  
  public :

    FittedSn ();
  virtual ~FittedSn();
  const std::string&  GetName() const {return Name;};
  double GetZ () const {return RedShift;};
  int GetGType () const {return Gal_Type;};
  const FitParams&  GetParams() const {return params;};
  int GetGroup() const {return group;};
  void SetGroup(int g) {group = g;};
  const FitParams* Params() const {return &params;};
  int GetSet() const {return Set;};
  void SetSet(int i) {Set=i;};
  

  LcParam *mag;   // SN magnitude
  LcParam *shape; // SN light-curve shape parameter (stretch-1 for SALT1 or SIFTO, X1 for SALT2)
  LcParam *color; // SN color
  


  // R&D things
  
 
#ifdef WITH_HOST_EXTINCTION
  private : 
  bool has_extinction_measurement; // EBV with Cardelli law
  public :
  bool HasExtinctionMeasurement() const {return has_extinction_measurement;};
  LcParam *ebv;
#endif

#ifdef WITH_UV_FIT
 private :
  bool has_uv_fit; 
 public :
  bool HasUVFit() const {return has_uv_fit;};
  LcParam *uv;
#endif

};


class AllSn : public std::list<CountedRef<FittedSn> >

{

  private :
    int number_of_salt2_components; // X0 X1 ...
  LcModel model; // which lc fitter was used
  std::vector<int> galaxy_types;
#ifdef WITH_HOST_EXTINCTION 
  bool has_extinction_measurement; // EBV with Cardelli law
#endif
#ifdef WITH_UV_FIT
  bool has_uv_fit; 
#endif
  
  public :
    AllSn () {
    number_of_salt2_components=2;
    model=UNKNOWN;
#ifdef WITH_HOST_EXTINCTION 
    has_extinction_measurement=false;
#endif
#ifdef WITH_UV_FIT
    has_uv_fit=false;
#endif
    };
  void ReadDictFile(const std::string& dictfilename);  
  LcModel GetLcModel() const {return model;};
#ifdef WITH_HOST_EXTINCTION 
  bool HasExtinctionMeasurement() const {return has_extinction_measurement;};
#endif
#ifdef WITH_UV_FIT
  bool HasUVFit() const {return has_uv_fit;};
#endif

  ~AllSn() {};
  int NumberOfSALT2Components() const {return number_of_salt2_components;};
  void SetNumberOfSALT2Components(int n)  {number_of_salt2_components=n;};
  size_t NumberOfGalaxyTypes() const {return galaxy_types.size();};
  

};

typedef AllSn::iterator SnIterator;
typedef AllSn::const_iterator SnCIterator;



#endif /* FITTEDSN__H */
